@@ -7,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QEvent/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -24,11 +24,18 @@ Qt::Gui::QDragResponseEvent
 
 =over
 
-=item    QDragResponseEvent(bool accepted)
+=item   QDragResponseEvent(bool accepted)
 
-=item    ~QDragResponseEvent()
+=item   ~QDragResponseEvent()
 
-=item   bool dragAccepted()
+=item  bool dragAccepted()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
