@@ -7,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QEvent/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -24,13 +24,20 @@ Qt::Gui::QGraphicsSceneEvent
 
 =over
 
-=item    QGraphicsSceneEvent(QGraphicsSceneEvent::Type type)
+=item   QGraphicsSceneEvent(QGraphicsSceneEvent::Type type)
 
-=item    ~QGraphicsSceneEvent()
+=item   ~QGraphicsSceneEvent()
 
-=item   void setWidget(QWidget * widget)
+=item  void setWidget(QWidget * widget)
 
-=item   QWidget * widget()
+=item  QWidget * widget()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
