@@ -7,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QEvent/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -24,21 +24,28 @@ Qt::Gui::QHelpEvent
 
 =over
 
-=item    QHelpEvent(QHelpEvent::Type type, const QPoint & pos, const QPoint & globalPos)
+=item   QHelpEvent(QHelpEvent::Type type, const QPoint & pos, const QPoint & globalPos)
 
-=item    ~QHelpEvent()
+=item   ~QHelpEvent()
 
-=item   const QPoint & globalPos()
+=item  const QPoint & globalPos()
 
-=item   int globalX()
+=item  int globalX()
 
-=item   int globalY()
+=item  int globalY()
 
-=item   const QPoint & pos()
+=item  const QPoint & pos()
 
-=item   int x()
+=item  int x()
 
-=item   int y()
+=item  int y()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
