@@ -7,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QEvent/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -24,7 +24,22 @@ Qt::Gui::QInputEvent
 
 =over
 
-=item    ~QInputEvent()
+=item   QInputEvent(QInputEvent::Type type, QFlags<Qt::KeyboardModifier> modifiers)
+
+=item   QInputEvent(QInputEvent::Type type, QFlags<Qt::KeyboardModifier> modifiers = Qt::NoModifier)
+
+=item   ~QInputEvent()
+
+=item  QFlags<Qt::KeyboardModifier> modifiers()
+
+=item  void setModifiers(QFlags<Qt::KeyboardModifier> amodifiers)
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
