@@ -7,17 +7,12 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QWidget/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Gui::QWidget/;
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-sub Line() { 0 }
-sub Rectangle() { 1 }
-
 
 1;
 
@@ -29,25 +24,36 @@ Qt::Gui::QRubberBand
 
 =over
 
-=item    QRubberBand(QRubberBand::Shape arg0, QWidget * arg1 = 0)
+=item   QRubberBand(QRubberBand::Shape arg0, QWidget * arg1)
 
-=item    QRubberBand(QRubberBand::Shape arg0, QWidget * arg1)
+=item   QRubberBand(QRubberBand::Shape arg0, QWidget * arg1 = 0)
 
-=item    ~QRubberBand()
+=item   ~QRubberBand()
 
-=item   void move(const QPoint & p)
+=item  void move(const QPoint & p)
 
-=item   void move(int x, int y)
+=item  void move(int x, int y)
 
-=item   void resize(const QSize & s)
+=item  void resize(const QSize & s)
 
-=item   void resize(int w, int h)
+=item  void resize(int w, int h)
 
-=item   void setGeometry(const QRect & r)
+=item  void setGeometry(const QRect & r)
 
-=item   void setGeometry(int x, int y, int w, int h)
+=item  void setGeometry(int x, int y, int w, int h)
 
-=item   QRubberBand::Shape shape()
+=item  QRubberBand::Shape shape()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+=item Line
+
+=item Rectangle
 
 
 =back
