@@ -7,13 +7,13 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Core::QEvent/;
 
 
 # FIXME: operator overload
 
 
-
 1;
 
 =head1 NAME
@@ -24,11 +24,18 @@ Qt::Gui::QStatusTipEvent
 
 =over
 
-=item    QStatusTipEvent(const QString & tip)
+=item   QStatusTipEvent(const QString & tip)
 
-=item    ~QStatusTipEvent()
+=item   ~QStatusTipEvent()
 
-=item   QString tip()
+=item  QString tip()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
 
 
 =back
