@@ -7,17 +7,12 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QStyleHintReturn/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Gui::QStyleHintReturn/;
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-sub Type() { 0 }
-sub Version() { 0 }
-
 
 1;
 
@@ -29,7 +24,18 @@ Qt::Gui::QStyleHintReturnMask
 
 =over
 
-=item    QStyleHintReturnMask()
+=item   QStyleHintReturnMask()
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+=item Type
+
+=item Version
 
 
 =back
