@@ -7,17 +7,12 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QStyleOption/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Gui::QStyleOption/;
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-sub Type() { 0 }
-sub Version() { 0 }
-
 
 1;
 
@@ -29,15 +24,24 @@ Qt::Gui::QStyleOptionComplex
 
 =over
 
-=item    QStyleOptionComplex(const QStyleOptionComplex & other)
+=item   QStyleOptionComplex(const QStyleOptionComplex & other)
 
-=item    QStyleOptionComplex(int version, int type = QStyleOptionComplex::SO_Complex)
+=item   QStyleOptionComplex(int version, int type)
 
-=item    QStyleOptionComplex(int version, int type)
+=item   QStyleOptionComplex(int version, int type = QStyleOptionComplex::SO_Complex)
 
-=item    QStyleOptionComplex(int version = QStyleOptionComplex::Version, int type = QStyleOptionComplex::SO_Complex)
+=item   QStyleOptionComplex(int version = QStyleOptionComplex::Version, int type = QStyleOptionComplex::SO_Complex)
 
-=item    QStyleOptionComplex(int version, int type = QStyleOptionComplex::SO_Complex)
+
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+=item Type
+
+=item Version
 
 
 =back
