@@ -7,23 +7,12 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QStyleOptionComplex/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Gui::QStyleOptionComplex/;
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-sub Type() { 0 }
-sub Version() { 0 }
-sub None() { 0 }
-sub Arrow() { 1 }
-sub Menu() { 2 }
-sub MenuButtonPopup() { 3 }
-sub PopupDelay() { 4 }
-sub HasMenu() { 5 }
-
 
 1;
 
@@ -35,9 +24,32 @@ Qt::Gui::QStyleOptionToolButton
 
 =over
 
-=item    QStyleOptionToolButton()
+=item   QStyleOptionToolButton()
 
-=item    QStyleOptionToolButton(const QStyleOptionToolButton & other)
+=item   QStyleOptionToolButton(const QStyleOptionToolButton & other)
+
+
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+=item Type
+
+=item Version
+
+=item None
+
+=item Arrow
+
+=item Menu
+
+=item MenuButtonPopup
+
+=item PopupDelay
+
+=item HasMenu
 
 
 =back
