@@ -7,17 +7,12 @@ use strict;
 use warnings;
 #use Carp;
 
-our $VERSION = '0.01_01';
-our $ISA     = qw/QInputEvent/;
+our $VERSION = '0.01_02';
+our $ISA     = qw/Qt::Gui::QInputEvent/;
 
 
 # FIXME: operator overload
 
-# enums
-# enum value in perl is enum item index number
-sub TouchScreen() { 0 }
-sub TouchPad() { 1 }
-
 
 1;
 
@@ -30,6 +25,17 @@ Qt::Gui::QTouchEvent
 =over
 
 
+=back
+
+=head1 ENUM VALUES
+
+=over
+
+=item TouchScreen
+
+=item TouchPad
+
+
 =back
 
 =head2 EXPORT
